@@ -1,13 +1,13 @@
-from . import pandas_bridge as pdextra
-from .base import (
-    _DiosBase,
-    _is_dios_like,
-    _is_bool_dios_like,
-)
+# SPDX-FileCopyrightText: 2021 Helmholtz-Zentrum für Umweltforschung GmbH - UFZ
+#
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 import numpy as np
 import pandas as pd
 
+from . import pandas_bridge as pdextra
+from .base import _DiosBase, _is_bool_dios_like, _is_dios_like
+
 
 class _Indexer:
     def __init__(self, obj: _DiosBase):
