@@ -25,6 +25,7 @@ DictLike = Union[
 _Field = str
 SelectT = Union[
     _Field,
+    Tuple[np.ndarray, _Field],
     Tuple[pd.Series, _Field],
     Tuple[pd.Index, _Field],
     Tuple[slice, _Field],
@@ -194,6 +195,8 @@ class Flags:
         self, raw_data: Optional[Union[DictLike, Flags]] = None, copy: bool = False
     ):
 
+        self._data: dict[str, History]
+
         if raw_data is None:
             raw_data = {}
 
