@@ -6,7 +6,7 @@
 
 # -*- coding: utf-8 -*-
 
-from typing import Callable, Tuple, Union
+from typing import TYPE_CHECKING, Callable, Union
 
 import numpy as np
 import pandas as pd
@@ -16,62 +16,65 @@ from saqc.core.flags import Flags
 from saqc.core.register import register
 from saqc.lib.tools import getFreqDelta
 
+if TYPE_CHECKING:
+    from saqc.core.core import SaQC
 
-@register(mask=["field"], demask=[], squeeze=[])
-def roll(
-    data: DictOfSeries,
-    field: str,
-    flags: Flags,
-    window: Union[str, int],
-    func: Callable[[pd.Series], np.ndarray] = np.mean,
-    min_periods: int = 0,
-    center: bool = True,
-    **kwargs
-) -> Tuple[DictOfSeries, Flags]:
-    """
-    Calculate a rolling-window function on the data.
 
-    Note, that the data gets assigned the worst flag present in the original data.
+class RollingMixin:
+    @register(mask=["field"], demask=[], squeeze=[])
+    def roll(
+        self: "SaQC",
+        field: str,
+        window: Union[str, int],
+        func: Callable[[pd.Series], np.ndarray] = np.mean,
+        min_periods: int = 0,
+        center: bool = True,
+        **kwargs
+    ) -> "SaQC":
+        """
+        Calculate a rolling-window function on the data.
 
-    Parameters
-    ----------
-    data : dios.DictOfSeries
-        The data.
-    field : str
-        The column to calculate on.
-    flags : saqc.Flags
-        Container to store quality flags to data.
-    window : {int, str}
-        The size of the window you want to roll with. If an integer is passed, the size
-        refers to the number of periods for every fitting window. If an offset string
-        is passed, the size refers to the total temporal extension. For regularly
-        sampled timeseries, the period number will be casted down to an odd number if
-        ``center=True``.
-    func : Callable, default np.mean
-        Function to roll with.
-    min_periods : int, default 0
-        The minimum number of periods to get a valid value
-    center : bool, default True
-        If True, center the rolling window.
+        Note, that the data gets assigned the worst flag present in the original data.
 
-    Returns
-    -------
-    data : dios.DictOfSeries
-        A dictionary of pandas.Series, holding all the data.
-        Data values may have changed relatively to the data input.
-    flags : saqc.Flags
-        The quality flags of data
-    """
-    return _roll(
-        data=data,
-        field=field,
-        flags=flags,
-        window=window,
-        func=func,
-        min_periods=min_periods,
-        center=center,
-        **kwargs,
-    )
+        Parameters
+        ----------
+        field : str
+            The column to calculate on.
+
+        flags : saqc.Flags
+            Container to store quality flags to data.
+
+        window : {int, str}
+            The size of the window you want to roll with. If an integer is passed, the size
+            refers to the number of periods for every fitting window. If an offset string
+            is passed, the size refers to the total temporal extension. For regularly
+            sampled timeseries, the period number will be casted down to an odd number if
+            ``center=True``.
+
+        func : Callable, default np.mean
+            Function to roll with.
+
+        min_periods : int, default 0
+            The minimum number of periods to get a valid value
+
+        center : bool, default True
+            If True, center the rolling window.
+
+        Returns
+        -------
+        saqc.SaQC
+        """
+        self._data, self._flags = _roll(
+            data=self._data,
+            field=field,
+            flags=self._flags,
+            window=window,
+            func=func,
+            min_periods=min_periods,
+            center=center,
+            **kwargs,
+        )
+        return self
 
 
 def _roll(
